==> oonsoo_1.1.orig.tar.gz: oonsoo-1.1.orig/Game/About.cxx <==
///////////////////////////////////////////////////////////////////////////////
// $Id: About.cxx,v 1.2 1996/01/03 20:10:47 bwmott Exp $
///////////////////////////////////////////////////////////////////////////////
//
// About.cxx - About Oonsoo class
//
//
// Bradford W. Mott
// Copyright (C) 1994
// December 13,1994
//
///////////////////////////////////////////////////////////////////////////////
// $Log: About.cxx,v $
// Revision 1.2  1996/01/03 20:10:47  bwmott
// Changed information displayed in the about dialog
//
// Revision 1.1  1995/01/08 06:42:42  bmott
// Initial revision
//
///////////////////////////////////////////////////////////////////////////////

#include "About.hxx"
#include "AboutOkOrCloseCommand.hxx"

#include "UIApplication.hxx"
#include "Frame.hxx"
#include "PushButton.hxx"
#include "DrawingArea.hxx"
#include "Text.hxx"
#include "Sprite.hxx"

///////////////////////////////////////////////////////////////////////////////
// Constructor 
///////////////////////////////////////////////////////////////////////////////
About::About(SpriteCollection* spriteCollection)
    : mySpriteCollection(spriteCollection)
{
  // Find the Oonsoo and B_Logo sprites
  Sprite* oonsoo = mySpriteCollection->getByName("Oonsoo");
  Sprite* b_logo = mySpriteCollection->getByName("B_Logo");

  // Determine width and height of the about window
  int height = 20+oonsoo->height()+20+55+10+b_logo->height()+10+90+10+30+20;
  int width = 100+oonsoo->width();

  // Build the about oonsoo window
  myToplevel = new TopLevel("About", 200, 200, width, height,
      new AboutOkOrCloseCommand(this));
  myToplevel->background("Gray65");

    // Put a frame in the window to make it look neat!
    Frame* frame = new Frame(myToplevel, "frame", 0, 0,
        width, height, Raised);
    frame->background("Gray65");

    // Build drawing area for Oonsoo title
    DrawingArea* drawingArea = new DrawingArea(myToplevel, "oonsoo",
        (width - oonsoo->width()) / 2, 20, oonsoo->width(), oonsoo->height());
    drawingArea->background(oonsoo);

    // Build Text widget for programmer information
    Text* text = new Text(myToplevel, "information",
        10, 20 + oonsoo->height() + 20, width-20, 55,
        "A Bradford W. Mott Production\nin association with\nSeunghee Lee");
    text->background("Gray65");

    // Build drawing area for B_Logo
    drawingArea = new DrawingArea(myToplevel, "b_logo",
        (width - b_logo->width()) / 2, height-20-30-10-90-10-b_logo->height(), 
        b_logo->width(), b_logo->height());
    drawingArea->background(b_logo);

    // Build Text widget for copyright information
    text = new Text(myToplevel, "copyright",
        10, height-20-30-10-90, width-20, 90,
        "Version 1.1\nCopyright (C) 1994, 1995, 1996\n\n"
        "http://www4.ncsu.edu/~bwmott/www/\nbwmott@eos.ncsu.edu");
    text->background("Gray65");

    // Build ok push button
    PushButton* pushButton = new PushButton(myToplevel, "ok",
         (width - 64) / 2, height-20-30,
         64, 30, "Ok", new AboutOkOrCloseCommand(this));
    pushButton->background("Gray65");

  // Manage the about window
  myToplevel->manage();
}

///////////////////////////////////////////////////////////////////////////////
// Destructor 
///////////////////////////////////////////////////////////////////////////////
About::~About()
{
  // Destroy the toplevel widget
  delete myToplevel;
}

==> oonsoo_1.2-1.tar.gz: oonsoo-1.2/Game/About.cxx <==
///////////////////////////////////////////////////////////////////////////////
// $Id: About.cxx,v 1.3 2000/01/10 23:25:37 bwmott Exp $
///////////////////////////////////////////////////////////////////////////////
//
// About.cxx - About Oonsoo class
//
//
// Bradford W. Mott
// Copyright (C) 1994
// December 13,1994
//
///////////////////////////////////////////////////////////////////////////////
// $Log: About.cxx,v $
// Revision 1.3  2000/01/10 23:25:37  bwmott
// Updated information displayed in the dialog
//
// Revision 1.2  1996/01/03 20:10:47  bwmott
// Changed information displayed in the about dialog
//
// Revision 1.1  1995/01/08 06:42:42  bmott
// Initial revision
//
///////////////////////////////////////////////////////////////////////////////

#include "About.hxx"
#include "AboutOkOrCloseCommand.hxx"

#include "UIApplication.hxx"
#include "Frame.hxx"
#include "PushButton.hxx"
#include "DrawingArea.hxx"
#include "Text.hxx"
#include "Sprite.hxx"

///////////////////////////////////////////////////////////////////////////////
// Constructor 
///////////////////////////////////////////////////////////////////////////////
About::About(SpriteCollection* spriteCollection)
    : mySpriteCollection(spriteCollection)
{
  // Find the Oonsoo and B_Logo sprites
  Sprite* oonsoo = mySpriteCollection->getByName("Oonsoo");
  Sprite* b_logo = mySpriteCollection->getByName("B_Logo");

  // Determine width and height of the about window
  int height = 20+oonsoo->height()+20+55+10+b_logo->height()+10+115+10+30+20;
  int width = 125+oonsoo->width();

  // Build the about oonsoo window
  myToplevel = new TopLevel("Oonsoo: About", 200, 200, width, height,
      new AboutOkOrCloseCommand(this));
  myToplevel->background("Gray70");

    // Put a frame in the window to make it look neat!
    Frame* frame = new Frame(myToplevel, "frame", 0, 0,
        width, height, Raised);
    frame->background("Gray70");

    // Build drawing area for Oonsoo title
    DrawingArea* drawingArea = new DrawingArea(myToplevel, "oonsoo",
        (width - oonsoo->width()) / 2, 20, oonsoo->width(), oonsoo->height());
    drawingArea->background(oonsoo);

    // Build Text widget for programmer information
    Text* text = new Text(myToplevel, "information",
        10, 20 + oonsoo->height() + 20, width-20, 55,
        "A Bradford W. Mott Production\nin association with\nSeunghee Lee");
    text->background("Gray70");

    // Build drawing area for B_Logo
    drawingArea = new DrawingArea(myToplevel, "b_logo",
        (width - b_logo->width()) / 2, height-20-30-10-115-10-b_logo->height(), 
        b_logo->width(), b_logo->height());
    drawingArea->background(b_logo);

    // Build Text widget for copyright information
    text = new Text(myToplevel, "copyright",
        10, height-20-30-10-115, width-20, 115,
        "Version 1.2\nCopyright (C) 1994 - 2000\nby Bradford W. Mott\n"
        "bwmott@acm.org\n\n"
        "Released under the GNU Public License");

    text->background("Gray70");

    // Build ok push button
    PushButton* pushButton = new PushButton(myToplevel, "ok",
         (width - 64) / 2, height-20-30,
         64, 30, "Ok", new AboutOkOrCloseCommand(this));
    pushButton->background("Gray70");

  // Manage the about window
  myToplevel->manage();
}

///////////////////////////////////////////////////////////////////////////////
// Destructor 
///////////////////////////////////////////////////////////////////////////////
About::~About()
{
  // Destroy the toplevel widget
  delete myToplevel;
}
